@@ -61,6 +61,9 @@ MainWindow::MainWindow(QWidget *parent, const Session& session) : KXmlGuiWindow(
     setupCentralWidget();
     setupStatusBar();
     setupActions();
+    // TODO: find a better fix for #351746 than QSize(0, 0);
+    setupGUI(QSize(0, 0), KXmlGuiWindow::Default, QStringLiteral("kronometerui.rc"));
+    slotInactive();    // inactive state is the default
     loadSettings();
 
     if (not m_session.isEmpty()) {
@@ -294,7 +297,7 @@ void MainWindow::slotCopyToClipboard()
 
 void MainWindow::setupCentralWidget()
 {
-    m_centralSplitter = new QSplitter(this);
+    auto splitter = new QSplitter(this);
 
     m_lapModel = new LapModel(this);
     auto proxyModel = new QSortFilterProxyModel(this);
@@ -308,14 +311,14 @@ void MainWindow::setupCentralWidget()
     m_lapView->resizeColumnsToContents();
     m_lapView->horizontalHeader()->setStretchLastSection(true);
     m_lapView->setSortingEnabled(true);
-    m_lapView->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Ignored);
+    m_lapView->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
 
-    m_centralSplitter->setOrientation(Qt::Horizontal);
-    m_centralSplitter->setChildrenCollapsible(false);
-    m_centralSplitter->addWidget(m_stopwatchDisplay);
-    m_centralSplitter->addWidget(m_lapView);
+    splitter->setOrientation(Qt::Horizontal);
+    splitter->setChildrenCollapsible(false);
+    splitter->addWidget(m_stopwatchDisplay);
+    splitter->addWidget(m_lapView);
 
-    setCentralWidget(m_centralSplitter);
+    setCentralWidget(splitter);
 }
 
 void MainWindow::setupStatusBar()
@@ -386,10 +389,6 @@ void MainWindow::setupActions()
     KStandardAction::open(this, SLOT(slotOpenSession()), actionCollection());
     KStandardAction::copy(this, SLOT(slotCopyToClipboard()), actionCollection());
     connect(m_exportAction, &QAction::triggered, this, &MainWindow::slotExportLapsAs);
-
-    setupGUI(Default, QStringLiteral("kronometerui.rc"));
-
-    slotInactive();    // inactive state is the default
 }
 
 void MainWindow::loadSettings()
